@@ -2,6 +2,7 @@ package Benchmark::Perl::Formance::Plugin::RegexpCommonTS;
 BEGIN {
   $Benchmark::Perl::Formance::Plugin::RegexpCommonTS::AUTHORITY = 'cpan:SCHWIGON';
 }
+# ABSTRACT: benchmark plugin - RegexpCommonTS - RegexpCommon test suite as benchmark
 
 use strict;
 use warnings;
@@ -88,15 +89,7 @@ __END__
 
 =head1 NAME
 
-Benchmark::Perl::Formance::Plugin::RegexpCommonTS
-
-=head1 NAME
-
-Benchmark::Perl::Formance::Plugin::RegexpCommonTS - RegexpCommon test suite as benchmark
-
-=head1 ABOUT
-
-This plugin runs a part of the RegexpCommon test suite.
+Benchmark::Perl::Formance::Plugin::RegexpCommonTS - benchmark plugin - RegexpCommonTS - RegexpCommon test suite as benchmark
 
 =head1 AUTHOR
 
