@@ -2,6 +2,7 @@ package Benchmark::Perl::Formance::Plugin::Shootout::binarytrees;
 BEGIN {
   $Benchmark::Perl::Formance::Plugin::Shootout::binarytrees::AUTHORITY = 'cpan:SCHWIGON';
 }
+# ABSTRACT: benchmark plugin - Shootout::binarytrees - Language shootout plugin: binarytrees
 
 # COMMAND LINE:
 # /usr/bin/perl binarytrees.perl-2.perl 20
@@ -107,7 +108,6 @@ sub main
                };
 }
 
-
 1;
 
 __END__
@@ -118,16 +118,7 @@ __END__
 
 =head1 NAME
 
-Benchmark::Perl::Formance::Plugin::Shootout::binarytrees
-
-=head1 NAME
-
-Benchmark::Perl::Formance::Plugin::Shootout::binarytrees - Language shootout plugin: binarytrees
-
-=head1 ABOUT
-
-This plugin does some runs the "binarytrees" benchmark from the
-Language Shootout.
+Benchmark::Perl::Formance::Plugin::Shootout::binarytrees - benchmark plugin - Shootout::binarytrees - Language shootout plugin: binarytrees
 
 =head1 AUTHOR
 
