@@ -2,6 +2,7 @@ package Benchmark::Perl::Formance::Plugin::Shootout::regexdna;
 BEGIN {
   $Benchmark::Perl::Formance::Plugin::Shootout::regexdna::AUTHORITY = 'cpan:SCHWIGON';
 }
+# ABSTRACT: benchmark plugin - Shootout::regexdna - Language shootout plugin: regexdna
 
 # COMMAND LINE:
 # /usr/bin/perl regexdna.perl-2.perl 0 < regexdna-input5000000.txt
@@ -126,16 +127,7 @@ __END__
 
 =head1 NAME
 
-Benchmark::Perl::Formance::Plugin::Shootout::regexdna
-
-=head1 NAME
-
-Benchmark::Perl::Formance::Plugin::Shootout::regexdna - Language shootout plugin: regexdna
-
-=head1 ABOUT
-
-This plugin does some runs the "regexdna" benchmark from the Language
-Shootout.
+Benchmark::Perl::Formance::Plugin::Shootout::regexdna - benchmark plugin - Shootout::regexdna - Language shootout plugin: regexdna
 
 =head1 AUTHOR
 
